@@ -2,14 +2,8 @@ print <<"EOF";
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 ! Emacs
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-Emacs.font:                     -*-courier-medium-r-*--14-*-*-*-*-*-${FONTSET}
-Emacs*menubar*Font:             -*-helvetica-bold-r-*--16-*-*-*-*-*-${FONTSET}
-Emacs*menubar*background:       grey
-Emacs*menubar*foreground:       grey30
-Emacs.background:               lightgray
-Emacs.foreground:               black
-Emacs.cursorColor:              red
-Emacs.bitmapIcon:               on
+Emacs.font:                     -*-terminus-medium-r-*--16-*-*-*-*-*-${FONTSET}
+Emacs*menubar*Font:             -*-helvetica-bold-r-*--14-*-*-*-*-*-${FONTSET}
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 ! A4 paper
@@ -48,8 +42,8 @@ XTerm*tek4014*fontLarge:     -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 Rxvt*font1:                  -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
 Rxvt*font2:                  -*-terminus-medium-r-*-*-14-*-*-*-*-*-${FONTSET}
-Rxvt*font3:                  -*-terminus-medium-r-*-*-16-*-*-*-*-*-${FONTSET}
-Rxvt*font:                   -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}
+Rxvt*font:                   -*-terminus-medium-r-*-*-16-*-*-*-*-*-${FONTSET}
+Rxvt*font3:                  -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}
 Rxvt*font4:                  -*-terminus-medium-r-*-*-24-*-*-*-*-*-${FONTSET}
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
@@ -57,8 +51,8 @@ Rxvt*font4:                  -*-terminus-medium-r-*-*-24-*-*-*-*-*-${FONTSET}
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 wterm*font1:                 -*-fixed-medium-r-*-*-10-*-*-*-*-60-${FONTSET}
 wterm*font2:                 -*-terminus-medium-r-*-*-14-*-*-*-*-*-${FONTSET}
-wterm*font3:                 -*-terminus-medium-r-*-*-16-*-*-*-*-*-${FONTSET}
-wterm*font:                  -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}
+wterm*font:                  -*-terminus-medium-r-*-*-16-*-*-*-*-*-${FONTSET}
+wterm*font3:                 -*-terminus-medium-r-*-*-20-*-*-*-*-*-${FONTSET}
 wterm*font4:                 -*-terminus-medium-r-*-*-24-*-*-*-*-*-${FONTSET}
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
