@@ -36,12 +36,14 @@ if ($IM_DEFAULT eq "Canna") {
 	print "if type uim-xim &> /dev/null ; then\n";
 	print "  uim-xim &\n";
 	print "fi\n";
-	print "XMODIFIERS=\@im=uim-anthy ; export XMODIFIERS\n";
+	print "XMODIFIERS=\@im=uim ; export XMODIFIERS\n";
+	print "UIM_IM_ENGINE=anthy ; export UIM_IM_ENGINE\n";
 } elsif ($IM_DEFAULT eq "PRIME") {
 	print "if type uim-xim &> /dev/null ; then\n";
 	print "  uim-xim &\n";
 	print "fi\n";
-	print "XMODIFIERS=\@im=uim-prime ; export XMODIFIERS\n";
+	print "XMODIFIERS=\@im=uim ; export XMODIFIERS\n";
+	print "UIM_IM_ENGINE=prime ; export UIM_IM_ENGINE\n";
 } 
 
 if ($IM_HOST{"Canna"} ne "") {
