@@ -13,13 +13,15 @@ export LANG
 #LC_MESSAGES=C
 #LC_TIME=C
 #LC_NUMERIC=C
-#export LC_MESSAGES LC_TIME LC_NUMERIC
+#export LC_MESSAGES
+#export LC_TIME
+#export LC_NUMERIC
 
 # Charset for MIME headers.
 MM_CHARSET=$ENCODING
 export MM_CHARSET
 
-# Needed for SGML-DSSSL processing.
+# Encoding for SGML-DSSSL processing.
 SP_ENCODING=$ENCODING
 export SP_ENCODING
 
@@ -27,28 +29,51 @@ EOF
 
 if ($EXTENDED) {
 	print <<"EOF";
+# Set the Turkish locale.
+LANG=$LOCALE
+export LANG
+
 # Setup the console font and keyboard.
-KEYB=$CKEYB
+KTYPE=$KTYPE
 FONT=$CFONT
 
 EOF
 	print <<'EOF';
+if [ "`locale charmap 2>/dev/null`" = "UTF-8" ]; then
+	case "$KTYPE" in
+		q|Q)		keyb="trqu"   ;;
+		f|F)		keyb="trfu"   ;;
+		alt|qalt|QALT)	keyb="tralt"  ;;
+		*)		keyb="trqu"   ;;
+	esac
+	umode="start"
+else
+	case "$KTYPE" in
+		q|Q)		keyb="trq"    ;;
+		f|F)		keyb="trf"    ;;
+		alt|qalt|QALT)	keyb="tralt"  ;;
+		*)		keyb="trq"    ;;
+	esac
+	umode="stop"
+fi
+
 case `tty` in
 	/dev/tty[0-9]*|/dev/vc/*)
-		if which consolechars >/dev/null 2>&1; then
+		(
+		if which consolechars; then
 			consolechars -f $FONT -m iso09
 		else
 			setfont $FONT -m trivial
 		fi
 		
-		if which loadkeys >/dev/null 2>&1; then
-			# Prepare unicode console if required, 
-			# and setup keyboard.
-			if echo $KEYB | grep -q 'tr[qf]u' && \
-				which kbd_mode >/dev/null 2>&1; then
-				kbd_mode -u && echo -ne '\033%G'
-			fi && loadkeys $KEYB >/dev/null 2>&1
+		if which loadkeys; then
+			# Prepare console mode and setup keyboard.
+			if which unicode_${umode}; then
+				unicode_${umode} 
+			fi
+			loadkeys $keyb
 		fi
+		) >/dev/null 2>&1
 		;;
 esac
 
